@@ -3,6 +3,4 @@
 from django.conf.urls import url
 from core import state_handler
 
-WEBSOCKET_URLPATTERNS = [
-    url(r"^state/$", state_handler.StateConsumer),
-]
+WEBSOCKET_URLPATTERNS = [url(r"^state/$", state_handler.StateConsumer)]
