@@ -94,11 +94,13 @@ class Settings(Stateful):
         settings_state["newMusicOnly"] = self.basic.new_music_only
         settings_state["loggingEnabled"] = self.basic.logging_enabled
         settings_state["embedStream"] = self.basic.embed_stream
+        settings_state["dynamicEmbeddedStream"] = self.basic.dynamic_embedded_stream
         settings_state["hashtagsActive"] = self.basic.hashtags_active
         settings_state["onlineSuggestions"] = self.basic.online_suggestions
         settings_state["numberOfSuggestions"] = self.basic.number_of_suggestions
         settings_state["peopleToParty"] = self.basic.people_to_party
         settings_state["alarmProbability"] = self.basic.alarm_probability
+        settings_state["buzzerCooldown"] = self.basic.buzzer_cooldown
         settings_state["downvotesToKick"] = self.basic.downvotes_to_kick
         settings_state["maxDownloadSize"] = self.basic.max_download_size
         settings_state["additionalKeywords"] = self.basic.additional_keywords
@@ -124,6 +126,7 @@ class Settings(Stateful):
         settings_state["bluetoothScanning"] = self.sound.bluetoothctl is not None
         settings_state["bluetoothDevices"] = self.sound.bluetooth_devices
 
+        settings_state["feedCava"] = self.sound.feed_cava
         settings_state["output"] = self.sound.output
 
         try:
